@@ -68,7 +68,7 @@ class ManagementSystemController:
         :return: True if nginx is running, false otherwise
         """
         output = subprocess.run(constants.COMMANDS.NGINX_STATUS.split(" "), capture_output=True, text=True)
-        nginx_running = not ("not" in output.stdout)
+        nginx_running = "active (running)" in output.stdout or "active (exited)" in output.stdout
         return nginx_running
 
     @staticmethod
@@ -79,7 +79,7 @@ class ManagementSystemController:
         :return: True if PostgreSQL is running, false otherwise
         """
         output = subprocess.run(constants.COMMANDS.POSTGRESQL_STATUS.split(" "), capture_output=True, text=True)
-        postgresql_running = not ("not" in output.stdout)
+        postgresql_running = "active (running)" in output.stdout or "active (exited)" in output.stdout
         return postgresql_running
 
     @staticmethod
@@ -90,7 +90,7 @@ class ManagementSystemController:
         :return: True if Docker engine is running, false otherwise
         """
         output = subprocess.run(constants.COMMANDS.DOCKER_ENGINE_STATUS.split(" "), capture_output=True, text=True)
-        docker_engine_running = not ("not" in output.stdout)
+        docker_engine_running = "active (running)" in output.stdout or "active (exited)" in output.stdout
         return docker_engine_running
 
     @staticmethod
@@ -100,7 +100,7 @@ class ManagementSystemController:
 
         :return: True if it is running, false otherwise
         """
-        pid = ManagementSystemController.read_pid_file(constants.COMMANDS.MANAGEMENT_SYSTEM_PID_FILE)
+        pid = ManagementSystemController.read_pid_file(constants.COMMANDS.CSLE_MGMT_WEBAPP_PID_FILE)
         if pid == -1:
             return False
         cmd = (constants.COMMANDS.PS_AUX + constants.COMMANDS.SPACE_DELIM + constants.COMMANDS.PIPE_DELIM +
@@ -135,7 +135,7 @@ class ManagementSystemController:
         if ManagementSystemController.is_flask_running():
             return False
 
-        cmd = constants.COMMANDS.BUILD_MONITOR
+        cmd = constants.COMMANDS.BUILD_CSLE_MGMT_WEBAPP
         p = subprocess.Popen(cmd, stdout=subprocess.PIPE, shell=True)
         while True:
             out = p.stdout.read(1)
@@ -148,12 +148,12 @@ class ManagementSystemController:
                     pass
                 sys.stdout.flush()
 
-        cmd = constants.COMMANDS.START_MONITOR
+        cmd = constants.COMMANDS.START_CSLE_MGMT_WEBAPP
         p = subprocess.Popen(cmd, stdout=subprocess.DEVNULL, shell=True)
         p.communicate()
         pid = p.pid + 1
 
-        cmd = constants.COMMANDS.SAVE_PID.format(pid, constants.COMMANDS.MANAGEMENT_SYSTEM_PID_FILE)
+        cmd = constants.COMMANDS.SAVE_PID.format(pid, constants.COMMANDS.CSLE_MGMT_WEBAPP_PID_FILE)
         p = subprocess.Popen(cmd, stdout=subprocess.DEVNULL, shell=True)
         p.communicate()
         return True
@@ -182,7 +182,7 @@ class ManagementSystemController:
         """
         if not ManagementSystemController.is_flask_running():
             return False
-        pid = ManagementSystemController.read_pid_file(constants.COMMANDS.MANAGEMENT_SYSTEM_PID_FILE)
+        pid = ManagementSystemController.read_pid_file(constants.COMMANDS.CSLE_MGMT_WEBAPP_PID_FILE)
         cmd = constants.COMMANDS.KILL_PROCESS.format(pid)
         p = subprocess.Popen(cmd, stdout=subprocess.DEVNULL, shell=True)
         p.communicate()
@@ -468,6 +468,19 @@ class ManagementSystemController:
         (output, err) = p.communicate()
         return True
 
+    @staticmethod
+    def stop_cluster_manager() -> bool:
+        """
+        Stops the local cluster manager
+
+        :return: True if it was stopped, False otherwise
+        """
+        pid = ManagementSystemController.read_pid_file(constants.COMMANDS.CLUSTER_MANAGER_PIDFILE)
+        cmd = constants.COMMANDS.KILL_PROCESS.format(pid)
+        p = subprocess.Popen(cmd, stdout=subprocess.DEVNULL, shell=True)
+        (output, err) = p.communicate()
+        return True
+
     @staticmethod
     def is_pid_running(pid: int) -> bool:
         """
